@@ -70,15 +70,9 @@ class SharedBackendConf(SharedBackendConfUtils):
     def ldapLogin(self):
         return self._jconf.ldapLogin()
 
-    def proxyLoginOnly(self):
-        return self._jconf.proxyLoginOnly()
-
     def kerberosLogin(self):
         return self._jconf.kerberosLogin()
 
-    def pamLogin(self):
-        return self._jconf.pamLogin()
-
     def loginConf(self):
         return self._get_option(self._jconf.loginConf())
 
@@ -221,12 +215,12 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setExternalClusterMode()
         return self
 
-    def setCloudName(self, cloudName):
-        self._jconf.setCloudName(cloudName)
+    def setCloudName(self, value):
+        self._jconf.setCloudName(value)
         return self
 
-    def setNthreads(self, numThreads):
-        self._jconf.setNthreads(numThreads)
+    def setNthreads(self, value):
+        self._jconf.setNthreads(value)
         return self
 
     def setReplEnabled(self):
@@ -253,8 +247,8 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setModelPrintAfterTrainingDisabled()
         return self
 
-    def setDefaultNumReplSessions(self, numSessions):
-        self._jconf.setDefaultNumReplSessions(numSessions)
+    def setDefaultNumReplSessions(self, value):
+        self._jconf.setDefaultNumReplSessions(value)
         return self
 
     def setClusterTopologyListenerEnabled(self):
@@ -281,20 +275,20 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setFailOnUnsupportedSparkParamDisabled()
         return self
 
-    def setJks(self, path):
-        self._jconf.setJks(path)
+    def setJks(self, value):
+        self._jconf.setJks(value)
         return self
 
-    def setJksPass(self, password):
-        self._jconf.setJksPass(password)
+    def setJksPass(self, value):
+        self._jconf.setJksPass(value)
         return self
 
-    def setJksAlias(self, alias):
-        self._jconf.setJksAlias(alias)
+    def setJksAlias(self, value):
+        self._jconf.setJksAlias(value)
         return self
 
-    def setSslCACert(self, path):
-        self._jconf.setSslCACert(path)
+    def setSslCACert(self, value):
+        self._jconf.setSslCACert(value)
         return self
 
     def setHashLoginEnabled(self):
@@ -313,14 +307,6 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setLdapLoginDisabled()
         return self
 
-    def setProxyLoginOnlyEnabled(self):
-        self._jconf.setProxyLoginOnlyEnabled()
-        return self
-
-    def setProxyLoginOnlyDisabled(self):
-        self._jconf.setProxyLoginOnlyDisabled()
-        return self
-
     def setKerberosLoginEnabled(self):
         self._jconf.setKerberosLoginEnabled()
         return self
@@ -329,28 +315,20 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setKerberosLoginDisabled()
         return self
 
-    def setPamLoginEnabled(self):
-        self._jconf.setPamLoginEnabled()
+    def setLoginConf(self, value):
+        self._jconf.setLoginConf(value)
         return self
 
-    def setPamLoginDisabled(self):
-        self._jconf.setPamLoginDisabled()
+    def setUserName(self, value):
+        self._jconf.setUserName(value)
         return self
 
-    def setLoginConf(self, filePath):
-        self._jconf.setLoginConf(filePath)
+    def setPassword(self, value):
+        self._jconf.setPassword(value)
         return self
 
-    def setUserName(self, username):
-        self._jconf.setUserName(username)
-        return self
-
-    def setPassword(self, password):
-        self._jconf.setPassword(password)
-        return self
-
-    def setSslConf(self, path):
-        self._jconf.setSslConf(path)
+    def setSslConf(self, value):
+        self._jconf.setSslConf(value)
         return self
 
     def setAutoFlowSslEnabled(self):
@@ -361,32 +339,32 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setAutoFlowSslDisabled()
         return self
 
-    def setLogLevel(self, level):
-        self._jconf.setLogLevel(level)
+    def setLogLevel(self, value):
+        self._jconf.setLogLevel(value)
         return self
 
-    def setLogDir(self, dir):
-        self._jconf.setLogDir(dir)
+    def setLogDir(self, value):
+        self._jconf.setLogDir(value)
         return self
 
-    def setBackendHeartbeatInterval(self, interval):
-        self._jconf.setBackendHeartbeatInterval(interval)
+    def setBackendHeartbeatInterval(self, value):
+        self._jconf.setBackendHeartbeatInterval(value)
         return self
 
-    def setCloudTimeout(self, timeout):
-        self._jconf.setCloudTimeout(timeout)
+    def setCloudTimeout(self, value):
+        self._jconf.setCloudTimeout(value)
         return self
 
-    def setNodeNetworkMask(self, mask):
-        self._jconf.setNodeNetworkMask(mask)
+    def setNodeNetworkMask(self, value):
+        self._jconf.setNodeNetworkMask(value)
         return self
 
-    def setStacktraceCollectorInterval(self, interval):
-        self._jconf.setStacktraceCollectorInterval(interval)
+    def setStacktraceCollectorInterval(self, value):
+        self._jconf.setStacktraceCollectorInterval(value)
         return self
 
-    def setContextPath(self, contextPath):
-        self._jconf.setContextPath(contextPath)
+    def setContextPath(self, value):
+        self._jconf.setContextPath(value)
         return self
 
     def setFlowScalaCellAsyncEnabled(self):
@@ -397,28 +375,28 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setFlowScalaCellAsyncDisabled()
         return self
 
-    def setMaxParallelScalaCellJobs(self, limit):
-        self._jconf.setMaxParallelScalaCellJobs(limit)
+    def setMaxParallelScalaCellJobs(self, value):
+        self._jconf.setMaxParallelScalaCellJobs(value)
         return self
 
-    def setInternalPortOffset(self, offset):
-        self._jconf.setInternalPortOffset(offset)
+    def setInternalPortOffset(self, value):
+        self._jconf.setInternalPortOffset(value)
         return self
 
-    def setBasePort(self, port):
-        self._jconf.setBasePort(port)
+    def setBasePort(self, value):
+        self._jconf.setBasePort(value)
         return self
 
-    def setMojoDestroyTimeout(self, timeoutInMilliseconds):
-        self._jconf.setMojoDestroyTimeout(timeoutInMilliseconds)
+    def setMojoDestroyTimeout(self, value):
+        self._jconf.setMojoDestroyTimeout(value)
         return self
 
-    def setExtraProperties(self, extraProperties):
-        self._jconf.setExtraProperties(extraProperties)
+    def setExtraProperties(self, value):
+        self._jconf.setExtraProperties(value)
         return self
 
-    def setFlowExtraHttpHeaders(self, *args):
-        self._jconf.setFlowExtraHttpHeaders(*args)
+    def setFlowExtraHttpHeaders(self, value):
+        self._jconf.setFlowExtraHttpHeaders(value)
         return self
 
     def setFlowProxyRequestMaxSize(self, value):
@@ -445,16 +423,16 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setInsecureXGBoostDenied()
         return self
 
-    def setFlowDir(self, dir):
-        self._jconf.setFlowDir(dir)
+    def setFlowDir(self, value):
+        self._jconf.setFlowDir(value)
         return self
 
-    def setClientIp(self, ip):
-        self._jconf.setClientIp(ip)
+    def setClientIp(self, value):
+        self._jconf.setClientIp(value)
         return self
 
-    def setClientWebPort(self, port):
-        self._jconf.setClientWebPort(port)
+    def setClientWebPort(self, value):
+        self._jconf.setClientWebPort(value)
         return self
 
     def setClientVerboseEnabled(self):
@@ -465,20 +443,20 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setClientVerboseDisabled()
         return self
 
-    def setClientNetworkMask(self, mask):
-        self._jconf.setClientNetworkMask(mask)
+    def setClientNetworkMask(self, value):
+        self._jconf.setClientNetworkMask(value)
         return self
 
-    def setClientFlowBaseurlOverride(self, baseUrl):
-        self._jconf.setClientFlowBaseurlOverride(baseUrl)
+    def setClientFlowBaseurlOverride(self, value):
+        self._jconf.setClientFlowBaseurlOverride(value)
         return self
 
-    def setClientCheckRetryTimeout(self, timeout):
-        self._jconf.setClientCheckRetryTimeout(timeout)
+    def setClientCheckRetryTimeout(self, value):
+        self._jconf.setClientCheckRetryTimeout(value)
         return self
 
-    def setVerifySslCertificates(self, verify):
-        self._jconf.setVerifySslCertificates(verify)
+    def setVerifySslCertificates(self, value):
+        self._jconf.setVerifySslCertificates(value)
         return self
 
     def setSslHostnameVerificationInInternalRestConnectionsEnabled(self):
@@ -505,26 +483,26 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setKerberizedHiveDisabled()
         return self
 
-    def setHiveHost(self, host):
-        self._jconf.setHiveHost(host)
+    def setHiveHost(self, value):
+        self._jconf.setHiveHost(value)
         return self
 
-    def setHivePrincipal(self, principal):
-        self._jconf.setHivePrincipal(principal)
+    def setHivePrincipal(self, value):
+        self._jconf.setHivePrincipal(value)
         return self
 
-    def setHiveJdbcUrlPattern(self, pattern):
-        self._jconf.setHiveJdbcUrlPattern(pattern)
+    def setHiveJdbcUrlPattern(self, value):
+        self._jconf.setHiveJdbcUrlPattern(value)
         return self
 
-    def setHiveToken(self, token):
-        self._jconf.setHiveToken(token)
+    def setHiveToken(self, value):
+        self._jconf.setHiveToken(value)
         return self
 
-    def setIcedDir(self, dir):
-        self._jconf.setIcedDir(dir)
+    def setIcedDir(self, value):
+        self._jconf.setIcedDir(value)
         return self
 
-    def setRestApiTimeout(self, timeout):
-        self._jconf.setRestApiTimeout(timeout)
+    def setRestApiTimeout(self, value):
+        self._jconf.setRestApiTimeout(value)
         return self
