@@ -6,6 +6,7 @@ from h2o.exceptions import H2OValueError
 from h2o.utils.typechecks import assert_is_type
 from .extensions import has_extension
 from .model_base import ModelBase
+from ..utils.metaclass import deprecated_params
 
 
 class H2OBinomialModel(ModelBase):
@@ -754,7 +755,7 @@ class H2OBinomialModel(ModelBase):
         :param str timestep: A unit of measurement for the x-axis.
         :param str metric: A unit of measurement for the y-axis.
         :param bool server: if True, then generate the image inline (using matplotlib's "Agg" backend)
-        :param save_plot_path: a path to save the plot via using mathplotlib function savefig
+        :param save_plot_path: a path to save the plot via using matplotlib function savefig
         
         :returns: object that contains the resulting figure (can be accessed using result.figure())
 
@@ -852,6 +853,21 @@ class H2OBinomialModel(ModelBase):
         """
         return self._delegate_to_metrics('gains_lift', train, valid, xval)
 
+    @deprecated_params({'save_to_file': 'save_plot_path'})
+    def gains_lift_plot(self, type="both", xval=False, server=False, save_plot_path=None, plot=True):
+        """
+        Plot Gains/Lift curves.
+
+        :param type: one of "both", "gains", "lift". Defaults to "both".
+        :param xval: if True, use cross-validation metrics
+        :param server: if True, generate plot inline using matplotlib's "Agg" backend.
+        :param save_plot_path: filename to save the plot to
+        :param plot: True to plot curve, False to get a gains lift table
+
+        :returns: Gains lift table + the resulting plot (can be accessed using result.figure())
+        """
+        return self._delegate_to_metrics('gains_lift_plot', type=type, xval=xval, server=server, save_plot_path=save_plot_path, plot=plot)
+
     def kolmogorov_smirnov(self):
         """
         Retrieves a Kolmogorov-Smirnov metric for given binomial model. The number returned is in range between 0 and 1.
